@@ -1,7 +1,5 @@
-import importlib.metadata
-
 __name__ = "deciphon-api"
-__version__ = importlib.metadata.version(__name__)
+__version__ = "0.4.3"
 
 __all__ = [
     "__name__",
