@@ -9,6 +9,18 @@ from deciphon_api.models.seq import Seq
 router = APIRouter()
 
 
+@router.get(
+    "/seqs",
+    summary="get sequence list",
+    response_model=List[Seq],
+    status_code=HTTP_200_OK,
+    responses=responses,
+    name="seqs:get-sequence-list",
+)
+async def get_sequence_list():
+    return Seq.get_list()
+
+
 @router.get(
     "/seqs/{seq_id}",
     summary="get sequence",
@@ -17,17 +29,5 @@ router = APIRouter()
     responses=responses,
     name="seqs:get-sequence",
 )
-def get_sequence(seq_id: int = Path(..., gt=0)):
+async def get_sequence(seq_id: int = Path(..., gt=0)):
     return Seq.get(seq_id)
-
-
-@router.get(
-    "/seqs",
-    summary="get seq list",
-    response_model=List[Seq],
-    status_code=HTTP_200_OK,
-    responses=responses,
-    name="seqs:get-seq-list",
-)
-def get_seq_list():
-    return Seq.get_list()
